.. _index:

===============================================
boto: A Python interface to Amazon Web Services
===============================================

An integrated interface to current and future infrastructural services
offered by Amazon Web Services. 

Currently, this includes:

- Simple Storage Service (S3)
- Simple Queue Service (SQS)
- Elastic Compute Cloud (EC2)

 * Elastic Load Balancer (ELB)
 * CloudWatch
 * AutoScale

- Mechanical Turk
- SimpleDB (SDB) - See SimpleDbPage for details
- CloudFront
- Virtual Private Cloud (VPC)

Follow project updates on Twitter (http://twitter.com/pythonboto).

Follow Mitch on Twitter (http://twitter.com/garnaat).


Documentation Contents
----------------------

.. toctree::
   :maxdepth: 2

   sqs_tut
   s3_tut
   ec2_tut
   elb_tut
   autoscale_tut
   vpc_tut
   emr_tut
   ref/index
   documentation


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

